@@ -9,7 +9,7 @@ pub struct Attribute {
 }
 
 /// Creates a new Attribute.
-pub fn attr<K: ToString, V: ToString>(key: K, value: V) -> Attribute {
+pub fn attr(key: impl ToString, value: impl ToString) -> Attribute {
     Attribute {
         key: key.to_string(),
         value: value.to_string(),
@@ -31,7 +31,7 @@ mod tests {
         assert_eq!(attr("foo", "42"), expeceted);
         assert_eq!(attr("foo".to_string(), "42"), expeceted);
         assert_eq!(attr("foo", "42".to_string()), expeceted);
-        assert_eq!(attr("foo", Uint128(42)), expeceted);
+        assert_eq!(attr("foo", Uint128::new(42)), expeceted);
         assert_eq!(attr("foo", 42), expeceted);
     }
 }
